Join chat by code
^^^^^^^^^^^^^^^^^

Join chat process contains of:

#. verification "invitation code"
#. setting chat status to "ready"
#. generating "user token"
#. registering system message informing that chat is ready
